@@ -20,23 +20,20 @@ from io import BytesIO as StringIO
 from .core import docker_build, get_docker_client
 
 DETECTION_TEMPLATE="""
-FROM python:3-stretch as detector
+FROM python:3-slim-stretch as detector
 # Force the older version of debian for detector.
 # GLIBC is forwards compatible but not necessarily backwards compatible for pyinstaller
 # https://github.com/pyinstaller/pyinstaller/wiki/FAQ#gnulinux
 # StaticX is supposed to take care of this but there appears to be an issue when using subprocess
-
-LABEL stage=os_detect_builder
-
 RUN mkdir -p /tmp/distrovenv
 RUN python3 -m venv /tmp/distrovenv
-RUN . /tmp/distrovenv/bin/activate && pip install distro pyinstaller==4.0 staticx
-RUN apt-get update && apt-get install -qy patchelf #needed for staticx
-
-RUN echo 'import distro; import sys; output = (distro.name(), distro.version(), distro.codename()); print(output) if output[0] else sys.exit(1)' > /tmp/distrovenv/detect_os.py
+# patchelf needed for staticx
+# binutils provides objdump needed by pyinstaller
+RUN apt-get update && apt-get install -qy patchelf binutils
+RUN . /tmp/distrovenv/bin/activate && pip install distro pyinstaller==4.0 staticx==0.12.3
+RUN echo 'import distro; import sys; output = (distro.name(), distro.version(), distro.codename()); print(output) if distro.name() else sys.exit(1)' > /tmp/distrovenv/detect_os.py
 RUN . /tmp/distrovenv/bin/activate && pyinstaller --onefile /tmp/distrovenv/detect_os.py
-
-RUN . /tmp/distrovenv/bin/activate && staticx /dist/detect_os /dist/detect_os_static
+RUN . /tmp/distrovenv/bin/activate && staticx /dist/detect_os /dist/detect_os_static && chmod go+xr /dist/detect_os_static
 
 FROM %(image_name)s
 
